==> PyNFe-1.0.22.tar.gz: PyNFe-1.0.22/pynfe/nfce/manual_600/cancnfcesubst.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2019 All Rights Reserved. Luiz Fernando Maciel Franca
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2019, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from pynfe.nfe.manual_600.cancnfe_evento import InfEventoEnviado, EnvEvento, ProcEventoNFe
from pynfe.nfe.manual_600.cancnfe_evento import InfEventoRecebido, RetEvento, RetEnvEvento
from pynfe.xml_sped.base import TagCaracter, TagInteiro, ABERTURA

import os


DIRNAME = os.path.dirname(__file__)
ESQUEMA_ATUAL = 'Evento_CancSubst_v1.01'


class InfEnvEventoCancSubst(InfEventoEnviado):
    def __init__(self):
        super(InfEnvEventoCancSubst, self).__init__()
        self.tpEvento = TagCaracter(
            nome='tpEvento', codigo='P14', tamanho=[6, 6], raiz='//envEvento/infEvento',
            valor='110112')
        self.descEvento = TagCaracter(
            nome='descEvento', codigo='P19', tamanho=[5, 60],
            raiz='//envEvento/infEvento/detEvento', valor='Cancelamento por substituicao')
        self.cOrgaoAutor = TagInteiro(
            nome='cOrgaoAutor', codigo='P20', tamanho=[2, 2],
            raiz='//envEvento/infEvento/detEvento')
        self.tpAutor = TagInteiro(
            nome='tpAutor', codigo='P21', tamanho=[1, 1], raiz='//envEvento/infEvento/detEvento',
            valor=1)
        self.verAplic = TagCaracter(
            nome='verAplic', codigo='P22', tamanho=[1, 20], raiz='//envEvento/infEvento/detEvento',
            valor='SigNFe_v4.00')
        self.chNFeRef = TagCaracter(
            nome='chNFeRef', codigo='P31', tamanho=[44, 44], raiz='//envEvento/infEvento/detEvento')

    @property
    def xml(self):
        self.Id.valor = f'ID{self.tpEvento.valor}{self.chNFe.valor}{self.nSeqEvento.valor:02d}'
        xml = self.Id.xml
        xml += self.cOrgao.xml
        xml += self.tpAmb.xml
        xml += self.CNPJ.xml
        if self.CPF.valor:
            xml += self.CPF.xml
        xml += self.chNFe.xml
        xml += self.dhEvento.xml
        xml += self.tpEvento.xml
        xml += self.nSeqEvento.xml
        xml += self.verEvento.xml
        xml += self.versao.xml
        xml += self.descEvento.xml
        xml += self.cOrgaoAutor.xml
        xml += self.tpAutor.xml
        xml += self.verAplic.xml
        xml += self.nProt.xml
        xml += self.xJust.xml
        xml += self.chNFeRef.xml
        xml += '</detEvento>'
        xml += '</infEvento>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.Id.xml = arquivo
            self.cOrgao.xml = arquivo
            self.tpAmb.xml = arquivo
            self.CNPJ.xml = arquivo
            if self.CPF.valor:
                self.CPF.xml = arquivo
            self.chNFe.xml = arquivo
            self.dhEvento.xml = arquivo
            self.tpEvento.xml = arquivo
            self.nSeqEvento.xml = arquivo
            self.verEvento.xml = arquivo
            self.versao.xml = arquivo
            self.descEvento.xml = arquivo
            self.cOrgaoAutor.xml = arquivo
            self.tpAutor.xml = arquivo
            self.verAplic.xml = arquivo
            self.nProt.xml = arquivo
            self.xJust.xml = arquivo
            self.chNFeRef.xml = arquivo


class EnvEventoCancSubst(EnvEvento):
    def __init__(self):
        super(EnvEventoCancSubst, self).__init__()
        self.infEvento = InfEnvEventoCancSubst()
        self.caminho_esquema = os.path.join(DIRNAME, 'schema/', ESQUEMA_ATUAL + '/')
        self.arquivo_esquema = 'envEventoCancSubst_v1.00.xsd'

    @property
    def xml(self):
        xml = ABERTURA
        xml += self.versao.xml
        xml += self.idLote.xml
        xml += self.evento_versao.xml
        xml += self.infEvento.xml
        self.Signature.URI = '#' + self.infEvento.Id.valor
        xml += self.Signature.xml
        xml += '</evento>'
        xml += '</envEvento>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.infEvento.xml = arquivo
            self.Signature.xml = self._le_noh('//envEvento/sig:Signature')


class InfEventoRecebidoCancSubst(InfEventoRecebido):
    def __init__(self):
        super(InfEventoRecebidoCancSubst, self).__init__()
        self.cOrgaoAutor = TagInteiro(
            nome='cOrgaoAutor', codigo='R22', tamanho=[2, 2],
            raiz='//retEnvEvento/retEvento/infEvento')

    @property
    def xml(self):
        if self.Id.xml:
            xml = self.Id.xml
        else:
            xml = '<infEvento>'
        xml += self.tpAmb.xml
        xml += self.verAplic.xml
        xml += self.cOrgao.xml
        xml += self.cStat.xml
        xml += self.xMotivo.xml
        xml += self.chNFe.xml
        xml += self.tpEvento.xml
        xml += self.xEvento.xml
        xml += self.nSeqEvento.xml
        xml += self.cOrgaoAutor.xml
        xml += self.CNPJDest.xml
        if self.CPFDest.xml:
            xml += self.CPFDest.xml
        xml += self.emailDest.xml
        xml += self.dhRegEvento.xml
        xml += self.nProt.xml
        xml += '</infEvento>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.Id.xml = arquivo
            self.tpAmb.xml = arquivo
            self.verAplic.xml = arquivo
            self.cOrgao.xml = arquivo
            self.cStat.xml = arquivo
            self.xMotivo.xml = arquivo
            self.chNFe.xml = arquivo
            self.tpEvento.xml = arquivo
            self.xEvento.xml = arquivo
            self.nSeqEvento.xml = arquivo
            self.cOrgaoAutor.xml = arquivo
            self.CNPJDest.xml = arquivo
            if self.CPFDest.xml:
                self.CPFDest.xml = arquivo
            self.emailDest.xml = arquivo
            self.dhRegEvento.xml = arquivo
            self.nProt.xml = arquivo


class RetEventoCancSubst(RetEvento):
    def __init__(self):
        super(RetEventoCancSubst, self).__init__()
        self.infEvento = InfEventoRecebidoCancSubst()


class RetEnvEventoCancSubst(RetEnvEvento):
    def __init__(self):
        super(RetEnvEventoCancSubst, self).__init__()
        self.retEvento = RetEventoCancSubst()
        self.caminho_esquema = os.path.join(DIRNAME, 'schema/', ESQUEMA_ATUAL + '/')
        self.arquivo_esquema = 'retEnvEventoCancSubst_v1.00.xsd'

    @property
    def xml(self):
        xml = ABERTURA
        xml += self.versao.xml
        xml += self.idLote.xml
        xml += self.tpAmb.xml
        xml += self.verAplic.xml
        xml += self.cOrgao.xml
        xml += self.cStat.xml
        xml += self.xMotivo.xml
        xml += self.retEvento.xml
        xml += '</retEnvEvento>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.versao.xml = arquivo
            self.idLote.xml = arquivo
            self.tpAmb.xml = arquivo
            self.verAplic.xml = arquivo
            self.cOrgao.xml = arquivo
            self.cStat.xml = arquivo
            self.xMotivo.xml = arquivo
            self.retEvento.xml = arquivo


class ProcEventoCancSubst(ProcEventoNFe):
    def __init__(self):
        super(ProcEventoCancSubst, self).__init__()
        self.envEvento = EnvEventoCancSubst()
        self.retEnvEvento = RetEnvEventoCancSubst()
        self.caminho_esquema = os.path.join(DIRNAME, 'schema/', ESQUEMA_ATUAL + '/')
        self.arquivo_esquema = 'procEventoCancSubst_v1.00.xsd'

    @property
    def xml(self):
        xml = ABERTURA
        xml += self.versao.xml
        xml += self.envEvento.evento_versao.xml.replace(ABERTURA, '')
        xml += self.envEvento.infEvento.xml
        xml += self.envEvento.Signature.xml
        xml += '</evento>'
        xml += self.retEnvEvento.retEvento.xml.replace(ABERTURA, '')
        xml += '</procEventoNFe>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.envEvento.evento_versao.xml = arquivo
            self.envEvento.infEvento.xml = arquivo
            self.retEnvEvento.versao.xml = arquivo
            self.retEnvEvento.retEvento.xml = arquivo
            self.envEvento.Signature.xml = arquivo
            self.Signature.xml = self._le_noh('//procEventoNFe/sig:Signature')

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

==> PyNFe-5.0.11.tar.gz: PyNFe-5.0.11/pynfe/nfce/manual_600/cancnfcesubst.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2019 All Rights Reserved. Luiz Fernando Maciel Franca
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2019, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from pynfe.nfe.manual_600.cancnfe_evento import InfEventoEnviado, EnvEvento, ProcEventoNFe
from pynfe.nfe.manual_600.cancnfe_evento import InfEventoRecebido, RetEvento, RetEnvEvento
from pynfe.xml_sped.base import TagCaracter, TagInteiro, ABERTURA

import os


DIRNAME = os.path.dirname(__file__)
ESQUEMA_ATUAL = u'Evento_CancSubst_v1.01'


class InfEnvEventoCancSubst(InfEventoEnviado):
    def __init__(self):
        super(InfEnvEventoCancSubst, self).__init__()
        self.tpEvento = TagCaracter(
            nome=u'tpEvento', codigo=u'P14', tamanho=[6, 6], raiz=u'//envEvento/infEvento',
            valor=u'110112')
        self.descEvento = TagCaracter(
            nome=u'descEvento', codigo=u'P19', tamanho=[5, 60],
            raiz=u'//envEvento/infEvento/detEvento', valor=u'Cancelamento por substituicao')
        self.cOrgaoAutor = TagInteiro(
            nome=u'cOrgaoAutor', codigo=u'P20', tamanho=[2, 2],
            raiz=u'//envEvento/infEvento/detEvento')
        self.tpAutor = TagInteiro(
            nome=u'tpAutor', codigo=u'P21', tamanho=[1, 1], raiz=u'//envEvento/infEvento/detEvento',
            valor=1)
        self.verAplic = TagCaracter(
            nome=u'verAplic', codigo=u'P22', tamanho=[1, 20], raiz=u'//envEvento/infEvento/detEvento',
            valor=u'SigNFe_v4.00')
        self.chNFeRef = TagCaracter(
            nome=u'chNFeRef', codigo=u'P31', tamanho=[44, 44], raiz=u'//envEvento/infEvento/detEvento')

    @property
    def xml(self):
        ID = u'ID' + self.tpEvento.valor + self.chNFe.valor + u'%02d' % self.nSeqEvento.valor
        xml = self.Id.xml
        xml += self.cOrgao.xml
        xml += self.tpAmb.xml
        xml += self.CNPJ.xml
        if self.CPF.valor:
            xml += self.CPF.xml
        xml += self.chNFe.xml
        xml += self.dhEvento.xml
        xml += self.tpEvento.xml
        xml += self.nSeqEvento.xml
        xml += self.verEvento.xml
        xml += self.versao.xml
        xml += self.descEvento.xml
        xml += self.cOrgaoAutor.xml
        xml += self.tpAutor.xml
        xml += self.verAplic.xml
        xml += self.nProt.xml
        xml += self.xJust.xml
        xml += self.chNFeRef.xml
        xml += u'</detEvento>'
        xml += u'</infEvento>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.Id.xml = arquivo
            self.cOrgao.xml = arquivo
            self.tpAmb.xml = arquivo
            self.CNPJ.xml = arquivo
            if self.CPF.valor:
                self.CPF.xml = arquivo
            self.chNFe.xml = arquivo
            self.dhEvento.xml = arquivo
            self.tpEvento.xml = arquivo
            self.nSeqEvento.xml = arquivo
            self.verEvento.xml = arquivo
            self.versao.xml = arquivo
            self.descEvento.xml = arquivo
            self.cOrgaoAutor.xml = arquivo
            self.tpAutor.xml = arquivo
            self.verAplic.xml = arquivo
            self.nProt.xml = arquivo
            self.xJust.xml = arquivo
            self.chNFeRef.xml = arquivo


class EnvEventoCancSubst(EnvEvento):
    def __init__(self):
        super(EnvEventoCancSubst, self).__init__()
        self.infEvento = InfEnvEventoCancSubst()
        self.caminho_esquema = os.path.join(DIRNAME, u'schema/', ESQUEMA_ATUAL + u'/')
        self.arquivo_esquema = u'envEventoCancSubst_v1.00.xsd'

    @property
    def xml(self):
        xml = ABERTURA
        xml += self.versao.xml
        xml += self.idLote.xml
        xml += self.evento_versao.xml
        xml += self.infEvento.xml
        self.Signature.URI = u'#' + self.infEvento.Id.valor
        xml += self.Signature.xml
        xml += u'</evento>'
        xml += u'</envEvento>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.infEvento.xml = arquivo
            self.Signature.xml = self._le_noh(u'//envEvento/sig:Signature')


class InfEventoRecebidoCancSubst(InfEventoRecebido):
    def __init__(self):
        super(InfEventoRecebidoCancSubst, self).__init__()
        self.cOrgaoAutor = TagInteiro(
            nome=u'cOrgaoAutor', codigo=u'R22', tamanho=[2, 2],
            raiz=u'//retEnvEvento/retEvento/infEvento')

    @property
    def xml(self):
        if self.Id.xml:
            xml = self.Id.xml
        else:
            xml = u'<infEvento>'
        xml += self.tpAmb.xml
        xml += self.verAplic.xml
        xml += self.cOrgao.xml
        xml += self.cStat.xml
        xml += self.xMotivo.xml
        xml += self.chNFe.xml
        xml += self.tpEvento.xml
        xml += self.xEvento.xml
        xml += self.nSeqEvento.xml
        xml += self.cOrgaoAutor.xml
        xml += self.CNPJDest.xml
        if self.CPFDest.xml:
            xml += self.CPFDest.xml
        xml += self.emailDest.xml
        xml += self.dhRegEvento.xml
        xml += self.nProt.xml
        xml += u'</infEvento>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.Id.xml = arquivo
            self.tpAmb.xml = arquivo
            self.verAplic.xml = arquivo
            self.cOrgao.xml = arquivo
            self.cStat.xml = arquivo
            self.xMotivo.xml = arquivo
            self.chNFe.xml = arquivo
            self.tpEvento.xml = arquivo
            self.xEvento.xml = arquivo
            self.nSeqEvento.xml = arquivo
            self.cOrgaoAutor.xml = arquivo
            self.CNPJDest.xml = arquivo
            if self.CPFDest.xml:
                self.CPFDest.xml = arquivo
            self.emailDest.xml = arquivo
            self.dhRegEvento.xml = arquivo
            self.nProt.xml = arquivo


class RetEventoCancSubst(RetEvento):
    def __init__(self):
        super(RetEventoCancSubst, self).__init__()
        self.infEvento = InfEventoRecebidoCancSubst()


class RetEnvEventoCancSubst(RetEnvEvento):
    def __init__(self):
        super(RetEnvEventoCancSubst, self).__init__()
        self.retEvento = RetEventoCancSubst()
        self.caminho_esquema = os.path.join(DIRNAME, u'schema/', ESQUEMA_ATUAL + u'/')
        self.arquivo_esquema = u'retEnvEventoCancSubst_v1.00.xsd'

    @property
    def xml(self):
        xml = ABERTURA
        xml += self.versao.xml
        xml += self.idLote.xml
        xml += self.tpAmb.xml
        xml += self.verAplic.xml
        xml += self.cOrgao.xml
        xml += self.cStat.xml
        xml += self.xMotivo.xml
        xml += self.retEvento.xml
        xml += u'</retEnvEvento>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.versao.xml = arquivo
            self.idLote.xml = arquivo
            self.tpAmb.xml = arquivo
            self.verAplic.xml = arquivo
            self.cOrgao.xml = arquivo
            self.cStat.xml = arquivo
            self.xMotivo.xml = arquivo
            self.retEvento.xml = arquivo


class ProcEventoCancSubst(ProcEventoNFe):
    def __init__(self):
        super(ProcEventoCancSubst, self).__init__()
        self.envEvento = EnvEventoCancSubst()
        self.retEnvEvento = RetEnvEventoCancSubst()
        self.caminho_esquema = os.path.join(DIRNAME, u'schema/', ESQUEMA_ATUAL + u'/')
        self.arquivo_esquema = u'procEventoCancSubst_v1.00.xsd'

    @property
    def xml(self):
        xml = ABERTURA
        xml += self.versao.xml
        xml += self.envEvento.evento_versao.xml.replace(ABERTURA, u'')
        xml += self.envEvento.infEvento.xml
        xml += self.envEvento.Signature.xml
        xml += u'</evento>'
        xml += self.retEnvEvento.retEvento.xml.replace(ABERTURA, u'')
        xml += u'</procEventoNFe>'

        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.envEvento.evento_versao.xml = arquivo
            self.envEvento.infEvento.xml = arquivo
            self.retEnvEvento.versao.xml = arquivo
            self.retEnvEvento.retEvento.xml = arquivo
            self.envEvento.Signature.xml = arquivo
            self.Signature.xml = self._le_noh(u'//procEventoNFe/sig:Signature')

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
